===============
API - RF Module
===============

.. module:: lannerpsp.sdk_rfm

.. currentmodule:: lannerpsp

Regular Classes
===============

The following classes are intended for general use with the devices they
represent. All classes in this section are concrete (not abstract).

RFM
---

.. autoclass:: RFM
    :members: get_power_status, set_power_status, get_sim_status, set_sim_status

Supported Platforms
===================

The following platforms have been verified and confirmed to be supported:

* `LEC-7242`_

.. _LEC-7242: https://lannerinc.com/products/intelligent-edge-appliances/embedded-platform/lec-7242
